diff -u chrony-1.24/debian/changelog chrony-1.24/debian/changelog
--- chrony-1.24/debian/changelog
+++ chrony-1.24/debian/changelog
@@ -1,3 +1,13 @@
+chrony (1.24-2.1) unstable; urgency=low
+
+  * Non-maintainer upload.
+  * Fix "fails to configure on installation": init script: remove calls to
+    pidof, check the return value of start-stop-daemon instead; don't treat an
+    already running chronyd as an error, and call putonline also in this case
+    (closes: #593145).
+
+ -- gregor herrmann <gregoa@debian.org>  Sun, 12 Sep 2010 14:43:40 +0200
+
 chrony (1.24-2) unstable; urgency=low
 
   * Fixed regression that caused default CHRONY_IOC_ lines to
diff -u chrony-1.24/debian/init.d chrony-1.24/debian/init.d
--- chrony-1.24/debian/init.d
+++ chrony-1.24/debian/init.d
@@ -51,9 +51,16 @@
 
 case "$1" in
     start)
-	start-stop-daemon --start --verbose --exec $DAEMON || { echo "$DAEMON already running."; exit 1; }
-	/bin/pidof $DAEMON > /dev/null || { echo "$DAEMON failed to start."; exit 1; }
-	putonline
+	start-stop-daemon --start --verbose --exec $DAEMON
+	case "$?" in
+		0|1) # daemon successfully started or already running
+			putonline
+			;;
+		2) # daemon could not be started
+			echo "$DAEMON failed to start."
+			exit 1
+			;;
+	esac
 	;;
     stop)
 	start-stop-daemon --stop --verbose --oknodo --exec $DAEMON
@@ -64,8 +71,16 @@
 	start-stop-daemon --stop --quiet --exec $DAEMON
 	sleep 1
 	start-stop-daemon --start --quiet --exec $DAEMON -- -r
-	/bin/pidof $DAEMON > /dev/null || { echo "$DAEMON failed to restart."; rm -f /var/run/chrony-ppp-up; exit 1; }
-	putonline
+	case "$?" in
+		0|1) # daemon successfully started or still running
+			putonline
+			;;
+		2) # daemon could not be started
+			echo "$DAEMON failed to restart."
+			rm -f /var/run/chrony-ppp-up
+			exit 1
+			;;
+	esac
 	;;
     *)
 	echo "Usage: /etc/init.d/chrony {start|stop|restart|force-reload}"
